summaryrefslogtreecommitdiffstats
path: root/korganizer/koeditordetails.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:14:12 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:14:12 -0600
commitfd5d099065a748cac49e20a13481f85666c53c71 (patch)
treea0f1672cd88eb0e69b9ddc2ed9b08ecd98538bd3 /korganizer/koeditordetails.h
parentb440a9c608596cd88efdb3bfa4661c5e37efbe4b (diff)
downloadtdepim-fd5d099065a748cac49e20a13481f85666c53c71.tar.gz
tdepim-fd5d099065a748cac49e20a13481f85666c53c71.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'korganizer/koeditordetails.h')
-rw-r--r--korganizer/koeditordetails.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/korganizer/koeditordetails.h b/korganizer/koeditordetails.h
index 10d61e213..bb4f7b109 100644
--- a/korganizer/koeditordetails.h
+++ b/korganizer/koeditordetails.h
@@ -52,12 +52,12 @@ class AddresseeLineEdit;
typedef CustomListViewItem<KCal::Attendee *> AttendeeListItem;
/** KOAttendeeListView is a child class of KListView which supports
* dropping of attendees (e.g. from kaddressbook) onto it. If an attendeee
* was dropped, the signal dropped(Attendee*) is emitted. Valid drop classes
* are KVCardDrag and TQTextDrag.
*/
-class KOAttendeeListView : public KListView
+class KOAttendeeListView : public TDEListView
{
Q_OBJECT
@@ -117,7 +117,7 @@ class KOEditorDetails : public KOAttendeeEditor
private:
bool mDisableItemUpdate;
- KListView *mListView;
+ TDEListView *mListView;
// KOEditorFreeBusy *mFreeBusy;
};
@@ -52,12 +52,12 @@ class AddresseeLineEdit;
typedef CustomListViewItem<KCal::Attendee *> AttendeeListItem;
-/** KOAttendeeListView is a child class of KListView which supports
+/** KOAttendeeListView is a child class of TDEListView which supports
* dropping of attendees (e.g. from kaddressbook) onto it. If an attendeee
* was dropped, the signal dropped(Attendee*) is emitted. Valid drop classes